@@ -8,7 +8,7 @@ This test suite checks the methods of the Account class of tmdbsimple.
 
 Created by Celia Oakley on 2013-11-05
 
-:copyright: (c) 2013-2018 by Celia Oakley.
+:copyright: (c) 2013-2020 by Celia Oakley.
 :license: GPLv3, see LICENSE for more details.
 """
 
@@ -44,93 +44,115 @@ class AccountTestCase(unittest.TestCase):
     # run this test with a valid session_id and authenticated account
     def test_account_info(self):
         username = USERNAME
-        acct = tmdb.Account(SESSION_ID)
-        response = acct.info()
-        self.assertEqual(acct.username, username)
+        account = tmdb.Account(SESSION_ID)
+        response = account.info()
+        self.assertEqual(account.username, username)
 
     def test_account_lists(self):
-        acct = tmdb.Account(SESSION_ID)
-        response = acct.info() # to set acct.id
-        response = acct.lists()
-        self.assertTrue(hasattr(acct, 'results'))
+        account = tmdb.Account(SESSION_ID)
+        response = account.info() # to set account.id
+        response = account.lists()
+        self.assertTrue(hasattr(account, 'results'))
 
     def test_account_favorite_movies(self):
         movietitle = MOVIETITLE
-        acct = tmdb.Account(SESSION_ID)
-        response = acct.info() # to set acct.id
-        response = acct.favorite_movies()
-        self.assertEqual(acct.results[0]['title'], movietitle)
+        account = tmdb.Account(SESSION_ID)
+        response = account.info() # to set account.id
+        response = account.favorite_movies()
+        self.assertEqual(account.results[0]['title'], movietitle)
 
     def test_account_favorite_tv(self):
         tvtitle = TVTITLE
-        acct = tmdb.Account(SESSION_ID)
-        response = acct.info() # to set acct.id
-        response = acct.favorite_tv()
-        self.assertEqual(acct.results[0]['name'], tvtitle)
+        account = tmdb.Account(SESSION_ID)
+        response = account.info() # to set account.id
+        response = account.favorite_tv()
+        self.assertEqual(account.results[0]['name'], tvtitle)
 
     def test_account_favorite(self):
         status_code = SUCCESSFUL_UPDATE
-        acct = tmdb.Account(SESSION_ID)
-        response = acct.info() # to set acct.id
+        account = tmdb.Account(SESSION_ID)
+        response = account.info() # to set account.id
         kwargs = {
             'media_type': 'movie', 
             'movie_id': FAVORITE_MOVIE_ID, 
             'favorite': True,
         }
-        response = acct.favorite(**kwargs)
-        self.assertEqual(acct.status_code, status_code)
+        response = account.favorite(**kwargs)
+        self.assertEqual(account.status_code, status_code)
 
     def test_account_rated_movies(self):
-        acct = tmdb.Account(SESSION_ID)
-        response = acct.info() # to set acct.id
+        account = tmdb.Account(SESSION_ID)
+        response = account.info() # to set account.id
         kwargs = {'page': 1, 'sort_by': 'created_at.asc'}
-        response = acct.rated_movies(**kwargs)
-        self.assertTrue(hasattr(acct, 'results'))
+        response = account.rated_movies(**kwargs)
+        self.assertTrue(hasattr(account, 'results'))
 
     def test_account_rated_tv(self):
-        acct = tmdb.Account(SESSION_ID)
-        response = acct.info() # to set acct.id
+        account = tmdb.Account(SESSION_ID)
+        response = account.info() # to set account.id
         kwargs = {'page': 1, 'sort_by': 'created_at.asc'}
-        response = acct.rated_tv(**kwargs)
-        self.assertTrue(hasattr(acct, 'results'))
+        response = account.rated_tv(**kwargs)
+        self.assertTrue(hasattr(account, 'results'))
+
+    def test_account_rated_tv_episodes(self):
+        account = tmdb.Account(SESSION_ID)
+        response = account.info() # to set account.id
+        kwargs = {'page': 1, 'sort_by': 'created_at.asc'}
+        response = account.rated_tv_episodes(**kwargs)
+        self.assertTrue(hasattr(account, 'results'))
 
     def test_account_watchlist_movies(self):
         movietitle = MOVIETITLE
-        acct = tmdb.Account(SESSION_ID)
-        response = acct.info() # to set acct.id
+        account = tmdb.Account(SESSION_ID)
+        response = account.info() # to set account.id
         kwargs = {'page': 1, 'sort_by': 'created_at.asc'}
-        response = acct.watchlist_movies(**kwargs)
-        self.assertEqual(acct.results[0]['title'], movietitle)
+        response = account.watchlist_movies(**kwargs)
+        self.assertEqual(account.results[0]['title'], movietitle)
 
     def test_account_watchlist_tv(self):
         tvtitle = TVTITLE
-        acct = tmdb.Account(SESSION_ID)
-        response = acct.info() # to set acct.id
+        account = tmdb.Account(SESSION_ID)
+        response = account.info() # to set account.id
         kwargs = {'page': 1, 'sort_by': 'created_at.asc'}
-        response = acct.watchlist_tv(**kwargs)
-        self.assertEqual(acct.results[0]['name'], tvtitle)
+        response = account.watchlist_tv(**kwargs)
+        self.assertEqual(account.results[0]['name'], tvtitle)
 
     def test_account_watchlist(self):
         status_code = SUCCESSFUL_UPDATE
-        acct = tmdb.Account(SESSION_ID)
-        response = acct.info() # to set acct.id
+        account = tmdb.Account(SESSION_ID)
+        response = account.info() # to set account.id
         kwargs = {
             'media_type': 'movie', 
             'media_id': WATCHLIST_MEDIA_ID, 
             'watchlist': 'true',
         }
-        response = acct.watchlist(**kwargs)
-        self.assertEqual(acct.status_code, status_code)
+        response = account.watchlist(**kwargs)
+        self.assertEqual(account.status_code, status_code)
 
 
 class AuthenticationTestCase(unittest.TestCase):
+    def test_authentication_guest_session_new(self):
+        success = True
+        auth = tmdb.Authentication()
+        response = auth.guest_session_new()
+        self.assertEqual(auth.success, success)
+
     def test_authentication_token_new(self):
         success = True
         auth = tmdb.Authentication()
         response = auth.token_new()
-        #print(auth.request_token)
         self.assertEqual(auth.success, success)
 
+        # Example usage only.
+        # User needs to approve request token, so would error here.
+        # See https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id.
+        # test_authentication_session_new(self):
+        #kwargs = {'request_token': auth.request_token}
+        #success = True
+        #auth = tmdb.Authentication()
+        #response = auth.session_new(**kwargs)
+        #self.assertEqual(auth.success, success)
+
         # test_authentication_token_validate_with_login(self):
         kwargs = {
             'request_token': auth.request_token,
@@ -142,20 +164,6 @@ class AuthenticationTestCase(unittest.TestCase):
         response = auth.token_validate_with_login(**kwargs)
         self.assertEqual(auth.success, success)
 
-        # test_authentication_session_new(self):
-        kwargs = {'request_token': auth.request_token}
-        success = True
-        auth = tmdb.Authentication()
-        response = auth.session_new(**kwargs)
-        #print(auth.session_id)
-        self.assertEqual(auth.success, success)
-
-    def test_authentication_guest_session_new(self):
-        success = True
-        auth = tmdb.Authentication()
-        response = auth.guest_session_new()
-        self.assertEqual(auth.success, success)
-
 
 class GuestSessionsTestCase(unittest.TestCase):
     def test_guest_sessions_rated_movies(self):
@@ -169,6 +177,28 @@ class GuestSessionsTestCase(unittest.TestCase):
         response = guest_session.rated_movies()
         self.assertTrue(hasattr(guest_session, 'results'))
 
+    def test_guest_sessions_rated_tv(self):
+        # get a guest session id
+        auth = tmdb.Authentication()
+        response = auth.guest_session_new()
+        guest_session_id = auth.guest_session_id
+
+        # get a list of rated tv shows for the guest session id 
+        guest_session = tmdb.GuestSessions(guest_session_id)
+        response = guest_session.rated_tv()
+        self.assertTrue(hasattr(guest_session, 'results'))
+
+    def test_guest_sessions_rated_tv_episodes(self):
+        # get a guest session id
+        auth = tmdb.Authentication()
+        response = auth.guest_session_new()
+        guest_session_id = auth.guest_session_id
+
+        # get a list of rated tv episodes for the guest session id 
+        guest_session = tmdb.GuestSessions(guest_session_id)
+        response = guest_session.rated_tv_episodes()
+        self.assertTrue(hasattr(guest_session, 'results'))
+
 
 class ListsTestCase(unittest.TestCase):
     def test_lists_info(self):
