@@ -7,7 +7,7 @@ This test suite checks the methods of the Movies class of tmdbsimple.
 
 Created by Celia Oakley on 2013-11-05
 
-:copyright: (c) 2013-2018 by Celia Oakley.
+:copyright: (c) 2013-2020 by Celia Oakley.
 :license: GPLv3, see LICENSE for more details.
 """
 
@@ -28,7 +28,7 @@ RATING = 7.5
 COLLECTION_ID = 10
 COLLECTION_NAME = 'Star Wars Collection'
 COMPANY_ID = 1
-COMPANY_NAME = 'Lucasfilm'
+COMPANY_NAME = 'Lucasfilm Ltd.'
 KEYWORD_ID = 1721
 KEYWORD_NAME = 'fight'
 REVIEW_ID = '5013bc76760ee372cb00253e'
@@ -55,12 +55,24 @@ class MoviesTestCase(unittest.TestCase):
         response = movie.info(language='fr')
         self.assertEqual(movie.title, title)
 
+    def test_movies_account_states(self):
+        id = MOVIE_ID_ALTERNATIVE
+        movie = tmdb.Movies(id)
+        response = movie.account_states(session_id=SESSION_ID)
+        self.assertTrue(hasattr(movie, 'favorite'))
+
     def test_movies_alternative_titles(self):
         id = MOVIE_ID_ALTERNATIVE
         movie = tmdb.Movies(id)
         response = movie.alternative_titles()
         self.assertTrue(hasattr(movie, 'titles'))
 
+    def test_movies_changes(self):
+        id = MOVIE_ID
+        movie = tmdb.Movies(id)
+        response = movie.changes()
+        self.assertTrue(hasattr(movie, 'changes'))
+
     def test_movies_credits(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
@@ -91,12 +103,6 @@ class MoviesTestCase(unittest.TestCase):
         response = movie.release_dates()
         self.assertTrue(hasattr(movie, 'results'))
 
-    def test_movies_releases(self):
-        id = MOVIE_ID
-        movie = tmdb.Movies(id)
-        response = movie.releases()
-        self.assertTrue(hasattr(movie, 'countries'))
-
     def test_movies_videos(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
@@ -109,18 +115,18 @@ class MoviesTestCase(unittest.TestCase):
         response = movie.translations()
         self.assertTrue(hasattr(movie, 'translations'))
 
-    def test_movies_similar_movies(self):
-        id = MOVIE_ID_ALTERNATIVE
-        movie = tmdb.Movies(id)
-        response = movie.similar_movies()
-        self.assertTrue(hasattr(movie, 'results'))
-
     def test_movies_recommendations(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
         response = movie.recommendations()
         self.assertTrue(hasattr(movie, 'results'))
 
+    def test_movies_similar_movies(self):
+        id = MOVIE_ID_ALTERNATIVE
+        movie = tmdb.Movies(id)
+        response = movie.similar_movies()
+        self.assertTrue(hasattr(movie, 'results'))
+
     def test_movies_reviews(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
@@ -133,22 +139,18 @@ class MoviesTestCase(unittest.TestCase):
         response = movie.lists()
         self.assertTrue(hasattr(movie, 'results'))
 
-    def test_movies_changes(self):
+    def test_movies_rating(self):
         id = MOVIE_ID
+        status_code = SUCCESSFUL_UPDATE
         movie = tmdb.Movies(id)
-        response = movie.changes()
-        self.assertTrue(hasattr(movie, 'changes'))
+        response = movie.rating(session_id=SESSION_ID, value=RATING)
+        self.assertEqual(movie.status_code, status_code)
 
     def test_movies_latest(self):
         movie = tmdb.Movies()
         response = movie.latest()
         self.assertTrue(hasattr(movie, 'popularity'))
 
-    def test_movies_upcoming(self):
-        movie = tmdb.Movies()
-        response = movie.upcoming()
-        self.assertTrue(hasattr(movie, 'results'))
-
     def test_movies_now_playing(self):
         movie = tmdb.Movies()
         response = movie.now_playing()
@@ -164,18 +166,16 @@ class MoviesTestCase(unittest.TestCase):
         response = movie.top_rated()
         self.assertTrue(hasattr(movie, 'results'))
 
-    def test_movies_account_states(self):
-        id = MOVIE_ID_ALTERNATIVE
-        movie = tmdb.Movies(id)
-        response = movie.account_states(session_id=SESSION_ID)
-        self.assertTrue(hasattr(movie, 'favorite'))
+    def test_movies_upcoming(self):
+        movie = tmdb.Movies()
+        response = movie.upcoming()
+        self.assertTrue(hasattr(movie, 'results'))
 
-    def test_movies_rating(self):
+    def test_movies_releases(self):
         id = MOVIE_ID
-        status_code = SUCCESSFUL_UPDATE
         movie = tmdb.Movies(id)
-        response = movie.rating(session_id=SESSION_ID, value=RATING)
-        self.assertEqual(movie.status_code, status_code)
+        response = movie.releases()
+        self.assertTrue(hasattr(movie, 'countries'))
 
 
 class CollectionsTestCase(unittest.TestCase):
@@ -192,6 +192,12 @@ class CollectionsTestCase(unittest.TestCase):
         response = collection.images()
         self.assertTrue(hasattr(collection, 'backdrops'))
 
+    def test_collections_translations(self):
+        id = COLLECTION_ID
+        collection = tmdb.Collections(id)
+        response = collection.translations()
+        self.assertTrue(hasattr(collection, 'translations'))
+
 
 class CompaniesTestCase(unittest.TestCase):
     def test_companies_info(self):
@@ -201,6 +207,18 @@ class CompaniesTestCase(unittest.TestCase):
         response = company.info()
         self.assertEqual(company.name, name)
 
+    def test_companies_alternative_names(self):
+        id = COMPANY_ID
+        company = tmdb.Companies(id)
+        response = company.alternative_names()
+        self.assertTrue(hasattr(company, 'results'))
+
+    def test_companies_images(self):
+        id = COMPANY_ID
+        company = tmdb.Companies(id)
+        response = company.images()
+        self.assertTrue(hasattr(company, 'logos'))
+
     def test_companies_movies(self):
         id = COMPANY_ID
         company = tmdb.Companies(id)
