@@ -8,7 +8,7 @@ This test suite checks the methods of the People class of tmdbsimple.
 
 Created by Celia Oakley on 2013-11-05
 
-:copyright: (c) 2013-2018 by Celia Oakley.
+:copyright: (c) 2013-2020 by Celia Oakley.
 :license: GPLv3, see LICENSE for more details.
 """
 
@@ -24,7 +24,7 @@ Constants
 PEOPLE_ID = 287
 PEOPLE_NAME = 'Brad Pitt'
 CREDITS_ID = '52542282760ee313280017f9'
-CREDITS_DEPARTMENT = 'Actors'
+CREDITS_DEPARTMENT = 'Acting'
 
 
 class PeopleTestCase(unittest.TestCase):
@@ -35,6 +35,12 @@ class PeopleTestCase(unittest.TestCase):
         response = person.info()
         self.assertEqual(person.name, name)
 
+    def test_people_changes(self):
+        id = PEOPLE_ID
+        person = tmdb.People(id)
+        response = person.changes()
+        self.assertTrue(hasattr(person, 'changes'))
+
     def test_people_movie_credits(self):
         id = PEOPLE_ID
         person = tmdb.People(id)
@@ -65,22 +71,28 @@ class PeopleTestCase(unittest.TestCase):
         response = person.images()
         self.assertTrue(hasattr(person, 'profiles'))
 
-    def test_people_changes(self):
+    def test_people_tagged_images(self):
         id = PEOPLE_ID
         person = tmdb.People(id)
-        response = person.changes()
-        self.assertTrue(hasattr(person, 'changes'))
-
-    def test_people_popular(self):
-        person = tmdb.People()
-        response = person.popular()
+        response = person.tagged_images()
         self.assertTrue(hasattr(person, 'results'))
 
+    def test_people_translations(self):
+        id = PEOPLE_ID
+        person = tmdb.People(id)
+        response = person.translations()
+        self.assertTrue(hasattr(person, 'translations'))
+
     def test_people_latest(self):
         person = tmdb.People()
         response = person.latest()
         self.assertTrue(hasattr(person, 'name'))
 
+    def test_people_popular(self):
+        person = tmdb.People()
+        response = person.popular()
+        self.assertTrue(hasattr(person, 'results'))
+
 
 class CreditsTestCase(unittest.TestCase):
     def test_credits_info(self):
