@@ -8,7 +8,7 @@ This test suite checks the methods of the Search class of tmdbsimple.
 
 Created by Celia Oakley on 2013-11-05
 
-:copyright: (c) 2013-2018 by Celia Oakley.
+:copyright: (c) 2013-2020 by Celia Oakley.
 :license: GPLv3, see LICENSE for more details.
 """
 
@@ -30,10 +30,10 @@ QUERY_7 = 'fight'
 QUERY_8 = 'blackjack'
 
 class SearchTestCase(unittest.TestCase):
-    def test_search_movies(self):
-        query = QUERY_1
+    def test_search_company(self):
+        query = QUERY_6
         search = tmdb.Search()
-        response = search.movie(query=query)
+        response = search.company(query=query)
         self.assertTrue(hasattr(search, 'results'))
 
     def test_search_collection(self):
@@ -42,10 +42,22 @@ class SearchTestCase(unittest.TestCase):
         response = search.collection(query=query)
         self.assertTrue(hasattr(search, 'results'))
 
-    def test_search_tv(self):
-        query = QUERY_3
+    def test_search_keyword(self):
+        query = QUERY_7
         search = tmdb.Search()
-        response = search.tv(query=query)
+        response = search.keyword(query=query)
+        self.assertTrue(hasattr(search, 'results'))
+
+    def test_search_movie(self):
+        query = QUERY_1
+        search = tmdb.Search()
+        response = search.movie(query=query)
+        self.assertTrue(hasattr(search, 'results'))
+
+    def test_search_multi(self):
+        query = QUERY_8
+        search = tmdb.Search()
+        response = search.multi(query=query)
         self.assertTrue(hasattr(search, 'results'))
 
     def test_search_person(self):
@@ -54,20 +66,8 @@ class SearchTestCase(unittest.TestCase):
         response = search.person(query=query)
         self.assertTrue(hasattr(search, 'results'))
 
-    def test_search_company(self):
-        query = QUERY_6
+    def test_search_tv(self):
+        query = QUERY_3
         search = tmdb.Search()
-        response = search.company(query=query)
-        self.assertTrue(hasattr(search, 'results'))
-
-    def test_search_keyword(self):
-        query = QUERY_7
-        search = tmdb.Search()
-        response = search.keyword(query=query)
-        self.assertTrue(hasattr(search, 'results'))
-
-    def test_search_multi(self):
-        query = QUERY_8
-        search = tmdb.Search()
-        response = search.multi(query=query)
+        response = search.tv(query=query)
         self.assertTrue(hasattr(search, 'results'))
