@@ -8,7 +8,7 @@ of tmdbsimple.
 
 Created by Celia Oakley on 2013-10-31.
 
-:copyright: (c) 2013-2017 by Celia Oakley
+:copyright: (c) 2013-2020 by Celia Oakley
 :license: GPLv3, see LICENSE for more details
 """
 
@@ -19,7 +19,7 @@ class Account(TMDB):
     """
     Account functionality.
 
-    See: http://docs.themoviedb.apiary.io/#account
+    See: https://developers.themoviedb.org/3/account
          https://www.themoviedb.org/documentation/api/sessions
     """
     BASE_PATH = 'account'
@@ -31,6 +31,7 @@ class Account(TMDB):
         'favorite': '/{id}/favorite',
         'rated_movies': '/{id}/rated/movies',
         'rated_tv': '/{id}/rated/tv',
+        'rated_tv_episodes': '/{id}/rated/tv/episodes',
         'watchlist_movies': '/{id}/watchlist/movies',
         'watchlist_tv': '/{id}/watchlist/tv',
         'watchlist': '/{id}/watchlist',
@@ -42,7 +43,7 @@ class Account(TMDB):
 
     def info(self, **kwargs):
         """
-        Get the basic information for an account.
+        Get your account details.
 
         Call this method first, before calling other Account methods.
 
@@ -59,7 +60,7 @@ class Account(TMDB):
         
     def lists(self, **kwargs):
         """
-        Get the lists that you have created and marked as a favorite.
+        Get all of the lists created by an account. Will include private lists if you are the owner.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -77,7 +78,7 @@ class Account(TMDB):
 
     def favorite_movies(self, **kwargs):
         """
-        Get the list of favorite movies for an account.
+        Get the list of your favorite movies.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -96,7 +97,7 @@ class Account(TMDB):
 
     def favorite_tv(self, **kwargs):
         """
-        Get the list of favorite TV series for an account.
+        Get the list of your favorite TV shows.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -115,7 +116,7 @@ class Account(TMDB):
 
     def favorite(self, **kwargs):
         """
-        Add or remove a movie to an accounts favorite list.
+        This method allows you to mark a movie or TV show as a favorite item.
 
         Args:
             media_type: 'movie' | 'tv'
@@ -140,7 +141,7 @@ class Account(TMDB):
 
     def rated_movies(self, **kwargs):
         """
-        Get the list of rated movies (and associated rating) for an account.
+        Get a list of all the movies you have rated.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -159,7 +160,7 @@ class Account(TMDB):
 
     def rated_tv(self, **kwargs):
         """
-        Get the list of rated TV shows (and associated rating) for an account.
+        Get a list of all the TV shows you have rated.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -176,9 +177,28 @@ class Account(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def rated_tv_episodes(self, **kwargs):
+        """
+        Get a list of all the TV episodes you have rated.
+
+        Args:
+            page: (optional) Minimum 1, maximum 1000.
+            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
+            language: (optional) ISO 639-1 code.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_id_path('rated_tv_episodes')
+        kwargs.update({'session_id': self.session_id})
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def watchlist_movies(self, **kwargs):
         """
-        Get the list of movies on an account watchlist.
+        Get a list of all the movies you have added to your watchlist.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -197,7 +217,7 @@ class Account(TMDB):
 
     def watchlist_tv(self, **kwargs):
         """
-        Get the list of TV series on an account watchlist.
+        Get a list of all the TV shows you have added to your watchlist.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -216,7 +236,7 @@ class Account(TMDB):
 
     def watchlist(self, **kwargs):
         """
-        Add or remove a movie to an accounts watch list.
+        Add a movie or TV show to your watchlist.
 
         Args:
             media_type: 'movie' | 'tv'
@@ -243,29 +263,48 @@ class Authentication(TMDB):
     """
     Authentication functionality.
 
-    See: http://docs.themoviedb.apiary.io/#authentication
+    See: https://developers.themoviedb.org/3/authentication
          https://www.themoviedb.org/documentation/api/sessions
     """
     BASE_PATH = 'authentication'
     URLS = {
-        'token_new': '/token/new',
-        'token_validate_with_login': '/token/validate_with_login',
-        'session_new': '/session/new', 
         'guest_session_new': '/guest_session/new', 
+        'token_new': '/token/new',
+        'session_new': '/session/new', 
+        'token_validate_with_login': '/token/validate_with_login',
     }
 
+    def guest_session_new(self, **kwargs):
+        """
+        This method will let you create a new guest session. Guest sessions
+        are a type of session that will let a user rate movies and TV shows
+        but not require them to have a TMDb user account. More
+        information about user authentication can be found here
+        (https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id).
+
+        Please note, you should only generate a single guest session per
+        user (or device) as you will be able to attach the ratings to a
+        TMDb user account in the future. There is also IP limits in place
+        so you should always make sure it's the end user doing the guest
+        session actions.
+
+        If a guest session is not used for the first time within 24 hours,
+        it will be automatically deleted.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_path('guest_session_new')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def token_new(self, **kwargs):
         """
-        Generate a valid request token for user based authentication.
-
-        A request token is required to ask the user for permission to
-        access their account.
-
-        After obtaining the request_token, either:
-        (1) Direct your user to:
-                https://www.themoviedb.org/authenticate/REQUEST_TOKEN
-        or:
-        (2) Call token_validate_with_login() below.
+        Create a temporary request token that can be used to validate a TMDb
+        user login. More details about how this works can be found here
+        (https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id).
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -276,30 +315,12 @@ class Authentication(TMDB):
         self._set_attrs_to_values(response)
         return response
 
-    def token_validate_with_login(self, **kwargs):
-        """
-        Authenticate a user with a TMDb username and password.  The user
-        must have a verified email address and be registered on TMDb.
-
-        Args:
-            request_token: The token you generated for the user to approve.
-            username: The user's username on TMDb.
-            password: The user's password on TMDb.
-
-        Returns:
-            A dict respresentation of the JSON returned from the API.
-        """
-        path = self._get_path('token_validate_with_login')
-
-        response = self._GET(path, kwargs)
-        self._set_attrs_to_values(response)
-        return response
-
     def session_new(self, **kwargs):
         """
-        Generate a session id for user based authentication.
-
-        A session id is required in order to use any of the write methods.
+        You can use this method to create a fully valid session ID once a user
+        has validated the request token. More information about how this works
+        can be found here
+        (https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id).
 
         Args:
             request_token: The token you generated for the user to approve.
@@ -315,28 +336,47 @@ class Authentication(TMDB):
         self._set_attrs_to_values(response)
         return response
 
-    def guest_session_new(self, **kwargs):
+    def token_validate_with_login(self, **kwargs):
         """
-        Generate a guest session id.
+        This method allows an application to validate a request token by entering
+        a username and password.
+
+        Not all applications have access to a web view so this can be used as a
+        substitute.
+
+        Please note, the preferred method of validating a request token is to
+        have a user authenticate the request via the TMDb website. You can read
+        about that method here
+        (https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id).
+
+        If you decide to use this method please use HTTPS.
+
+        Args:
+            username: The user's username on TMDb.
+            password: The user's password on TMDb.
+            request_token: The token you generated for the user to approve.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
-        path = self._get_path('guest_session_new')
+        path = self._get_path('token_validate_with_login')
 
         response = self._GET(path, kwargs)
         self._set_attrs_to_values(response)
         return response
 
+
 class GuestSessions(TMDB):
     """
     Guest Sessions functionality.
 
-    See: http://docs.themoviedb.apiary.io/#guestsessions
+    See: https://developers.themoviedb.org/3/guest-sessions
     """
     BASE_PATH = 'guest_session'
     URLS = {
-        'rated_movies': '/{guest_session_id}/rated_movies',
+        'rated_movies': '/{guest_session_id}/rated/movies',
+        'rated_tv': '/{guest_session_id}/rated/tv',
+        'rated_tv_episodes': '/{guest_session_id}/rated/tv/episodes',
     }
 
     def __init__(self, guest_session_id=0):
@@ -345,7 +385,7 @@ class GuestSessions(TMDB):
 
     def rated_movies(self, **kwargs):
         """
-        Get a list of rated moview for a specific guest session id.
+        Get the rated movies for a guest session.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -360,13 +400,49 @@ class GuestSessions(TMDB):
         response = self._GET(path, kwargs)
         self._set_attrs_to_values(response)
         return response
-    
+ 
+    def rated_tv(self, **kwargs):
+        """
+        Get the rated TV shows for a guest session.
+
+        Args:
+            page: (optional) Minimum 1, maximum 1000.
+            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
+            language: (optional) ISO 639-1 code.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_guest_session_id_path('rated_tv')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+ 
+    def rated_tv_episodes(self, **kwargs):
+        """
+        Get the rated TV episodes for a guest session.
+
+        Args:
+            page: (optional) Minimum 1, maximum 1000.
+            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
+            language: (optional) ISO 639-1 code.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_guest_session_id_path('rated_tv_episodes')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+ 
 
 class Lists(TMDB):
     """
     Lists functionality.
 
-    See: http://docs.themoviedb.apiary.io/#lists
+    See: https://developers.themoviedb.org/3/lists
     """
     BASE_PATH = 'list'
     URLS = {
@@ -385,7 +461,7 @@ class Lists(TMDB):
 
     def info(self, **kwargs):
         """
-        Get a list by id.
+        Get the details of a list.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -398,7 +474,8 @@ class Lists(TMDB):
 
     def item_status(self, **kwargs):
         """
-        Check to see if a movie id is already added to a list.
+        You can use this method to check if a movie has already been added to
+        the list.
 
         Args:
             movie_id: The id of the movie.
@@ -414,9 +491,7 @@ class Lists(TMDB):
 
     def create_list(self, **kwargs):
         """
-        Create a new list.
-
-        A valid session id is required.
+        Create a list.
 
         Args:
             name: Name of the list.
@@ -442,9 +517,7 @@ class Lists(TMDB):
 
     def add_item(self, **kwargs):
         """
-        Add new movies to a list that the user created.
-
-        A valid session id is required.
+        Add a movie to a list.
 
         Args:
             media_id: A movie id.
@@ -465,9 +538,7 @@ class Lists(TMDB):
         
     def remove_item(self, **kwargs):
         """
-        Delete movies from a list that the user created.
-
-        A valid session id is required.
+        Remove a movie from a list.
 
         Args:
             media_id: A movie id.
@@ -488,10 +559,7 @@ class Lists(TMDB):
 
     def clear_list(self, **kwargs):
         """
-        Clears all of the items within a list. This is an irreversible action
-        and should be treated with caution.
-
-        A valid session id is required.
+        Clear all of the items from a list.
 
         Args:
             confirm: True (do it) | False (don't do it)
