@@ -7,7 +7,7 @@ This module implements the Discover functionality of tmdbsimple.
 
 Created by Celia Oakley on 2013-10-31.
 
-:copyright: (c) 2013-2018 by Celia Oakley
+:copyright: (c) 2013-2020 by Celia Oakley
 :license: GPLv3, see LICENSE for more details
 """
 
@@ -27,8 +27,31 @@ class Discover(TMDB):
 
     def movie(self, **kwargs):
         """
-        Discover movies by different types of data like average rating, 
-        number of votes, genres and certifications.
+        Discover movies by different types of data like average rating, number
+        of votes, genres and certifications. You can get a valid list of
+        certifications from the certifications list method.
+
+        Discover also supports a nice list of sort options. See below for all
+        of the available options.
+
+        Please note, when using certification \ certification.lte you must also
+        specify certification_country. These two parameters work together in
+        order to filter the results. You can only filter results with the
+        countries we have added to our certifications list.
+
+        If you specify the region parameter, the regional release date will be
+        used instead of the primary release date. The date returned will be the
+        first date based on your query (ie. if a with_release_type is
+        specified). It's important to note the order of the release types that
+        are used. Specifying "2|3" would return the limited theatrical release
+        date as opposed to "3|2" which would return the theatrical date.
+
+        Also note that a number of filters support being comma (,) or pipe (|)
+        separated. Comma's are treated like an AND and query while pipe's are
+        an OR.
+
+        Some examples of what can be done with discover can be found at 
+        https://www.themoviedb.org/documentation/api/discover.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
@@ -79,7 +102,7 @@ class Discover(TMDB):
         """
         # Periods are not allowed in keyword arguments but several API 
         # arguments contain periods. See both usages in tests/test_discover.py.
-        for param in kwargs:
+        for param in dict(kwargs):
             if '_lte' in param:
                 kwargs[param.replace('_lte', '.lte')] = kwargs.pop(param)
             if '_gte' in param:
@@ -93,9 +116,19 @@ class Discover(TMDB):
 
     def tv(self, **kwargs):
         """
-        Discover TV shows by different types of data like average rating, 
+        Discover TV shows by different types of data like average rating,
         number of votes, genres, the network they aired on and air dates.
 
+        Discover also supports a nice list of sort options. See below for all
+        of the available options.
+
+        Also note that a number of filters support being comma (,) or pipe (|)
+        separated. Comma's are treated like an AND and query while pipe's are
+        an OR.
+
+        Some examples of what can be done with discover can be found at
+        https://www.themoviedb.org/documentation/api/discover. 
+
         Args:
             page: (optional) Minimum 1, maximum 1000.
             language: (optional) ISO 639-1 code.
@@ -134,7 +167,7 @@ class Discover(TMDB):
         """
         # Periods are not allowed in keyword arguments but several API 
         # arguments contain periods. See both usages in tests/test_discover.py.
-        for param in kwargs:
+        for param in dict(kwargs):
             if '_lte' in param:
                 kwargs[param.replace('_lte', '.lte')] = kwargs.pop(param)
             if '_gte' in param:
