@@ -8,7 +8,7 @@ Reviews functionality of tmdbsimple.
 
 Created by Celia Oakley on 2013-10-31.
 
-:copyright: (c) 2013-2018 by Celia Oakley
+:copyright: (c) 2013-2020 by Celia Oakley
 :license: GPLv3, see LICENSE for more details
 """
 
@@ -23,26 +23,27 @@ class Movies(TMDB):
     BASE_PATH = 'movie'
     URLS = {
         'info': '/{id}',
+        'account_states': '/{id}/account_states',
         'alternative_titles': '/{id}/alternative_titles',
+        'changes': '/{id}/changes',
         'credits': '/{id}/credits',
+        'external_ids': '/{id}/external_ids',
         'images': '/{id}/images',
         'keywords': '/{id}/keywords',
         'release_dates': '/{id}/release_dates',
-        'releases': '/{id}/releases',
         'videos': '/{id}/videos',
         'translations': '/{id}/translations',
+        'recommendations': '/{id}/recommendations',
         'similar_movies': '/{id}/similar_movies',
         'reviews': '/{id}/reviews',
         'lists': '/{id}/lists',
-        'changes': '/{id}/changes',
         'latest': '/latest',
-        'upcoming': '/upcoming',
         'now_playing': '/now_playing',
         'popular': '/popular',
         'top_rated': '/top_rated',
-        'account_states': '/{id}/account_states',
-        'rating': '/{id}/rating',
-        'recommendations': '/{id}/recommendations'
+        'upcoming': '/upcoming',
+        'rating': '/{id}/rating',     # backward compatability
+        'releases': '/{id}/releases', # backward compatability
     }
 
     def __init__(self, id=0):
@@ -51,14 +52,17 @@ class Movies(TMDB):
 
     def info(self, **kwargs):
         """
-        Get the basic movie information for a specific movie id.
+        Get the primary information about a movie.
+
+        Supports append_to_response. Read more about this at
+        https://developers.themoviedb.org/3/getting-started/append-to-response.
 
         Args:
             language: (optional) ISO 639-1 code.
             append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('info')
 
@@ -66,16 +70,35 @@ class Movies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def account_states(self, **kwargs):
+        """
+        Grab the following account states for a session:
+            - Movie rating
+            - If it belongs to your watchlist
+            - If it belongs to your favourite list
+
+        Args:
+            session_id: see Authentication.
+
+        Returns:
+            A dict representation of the JSON returned from the API.
+        """
+        path = self._get_id_path('account_states')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def alternative_titles(self, **kwargs):
         """
-        Get the alternative titles for a specific movie id.
+        Get all of the alternative titles for a movie.
 
         Args:
             country: (optional) ISO 3166-1 code.
             append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('alternative_titles')
 
@@ -83,15 +106,35 @@ class Movies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def changes(self, **kwargs):
+        """
+        Get the changes for a movie. By default only the last 24 hours are returned.
+
+        You can query up to 14 days in a single query by using the start_date
+        and end_date query parameters.
+
+        Args:
+            start_date: (optional) Expected format is 'YYYY-MM-DD'.
+            end_date: (optional) Expected format is 'YYYY-MM-DD'.
+
+        Returns:
+            A dict representation of the JSON returned from the API.
+        """
+        path = self._get_id_path('changes')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def credits(self, **kwargs):
         """
-        Get the cast and crew information for a specific movie id.
+        Get the cast and crew for a movie.
 
         Args:
             append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('credits')
 
@@ -99,9 +142,36 @@ class Movies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def external_ids(self, **kwargs):
+        """
+        Get the external ids for a movie. We currently support the following
+        external sources.
+
+        Media Databases - IMDb
+        Social IDs - Facebok, Instagram, Twitter
+
+        Args:
+            language: (optional) ISO 639-1 code.
+            append_to_response: (optional) Comma separated, any movie method.
+
+        Returns:
+            A dict representation of the JSON returned from the API.
+        """
+        path = self._get_id_path('external_ids')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def images(self, **kwargs):
         """
-        Get the images (posters and backdrops) for a specific movie id.
+        Get the images that belong to a movie.
+
+        Querying images with a language parameter will filter the results. If
+        you want to include a fallback language (especially useful for
+        backdrops) you can use the include_image_language parameter. This
+        should be a comma seperated value like so:
+        include_image_language=en,null.
 
         Args:
             language: (optional) ISO 639-1 code.
@@ -110,7 +180,7 @@ class Movies(TMDB):
                                     ISO 69-1.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('images')
 
@@ -120,10 +190,10 @@ class Movies(TMDB):
 
     def keywords(self):
         """
-        Get the plot keywords for a specific movie id.
+        Get the keywords that have been added to a movie.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('keywords')
 
@@ -131,6 +201,63 @@ class Movies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def release_dates(self, **kwargs):
+        """
+        Get the release date along with the certification for a movie.
+
+        Release dates support different types:
+
+            1. Premiere
+            2. Theatrical (limited)
+            3. Theatrical
+            4. Digital
+            5. Physical
+            6. TV
+
+        Args:
+            append_to_response: (optional) Comma separated, any movie method.
+
+        Returns:
+            A dict representation of the JSON returned from the API.
+        """
+        path = self._get_id_path('release_dates')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
+    def videos(self, **kwargs):
+        """
+        Get the videos that have been added to a movie.
+
+        Args:
+            append_to_response: (optional) Comma separated, any movie method.
+
+        Returns:
+            A dict representation of the JSON returned from the API.
+        """
+        path = self._get_id_path('videos')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
+    def translations(self, **kwargs):
+        """
+        Get a list of translations that have been created for a movie.
+
+        Args:
+            append_to_response: (optional) Comma separated, any movie method.
+
+        Returns:
+            A dict representation of the JSON returned from the API.
+        """
+        path = self._get_id_path('translations')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def recommendations(self, **kwargs):
         """
         Get a list of recommended movies for a movie.
@@ -140,7 +267,7 @@ class Movies(TMDB):
             page: (optional) Minimum value of 1.  Expected value is an integer.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('recommendations')
 
@@ -148,75 +275,12 @@ class Movies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
-    def release_dates(self, **kwargs):
-        """
-        Get the release dates and certification for a specific movie id.
-
-        Args:
-            append_to_response: (optional) Comma separated, any movie method.
-
-        Returns:
-            A dict respresentation of the JSON returned from the API.
-        """
-        path = self._get_id_path('release_dates')
-
-        response = self._GET(path, kwargs)
-        self._set_attrs_to_values(response)
-        return response
-
-    def releases(self, **kwargs):
-        """
-        Get the release date and certification information by country for a
-        specific movie id.
-
-        Args:
-            append_to_response: (optional) Comma separated, any movie method.
-
-        Returns:
-            A dict respresentation of the JSON returned from the API.
-        """
-        path = self._get_id_path('releases')
-
-        response = self._GET(path, kwargs)
-        self._set_attrs_to_values(response)
-        return response
-
-    def videos(self, **kwargs):
-        """
-        Get the videos (trailers, teasers, clips, etc...) for a
-        specific movie id.
-
-        Args:
-            append_to_response: (optional) Comma separated, any movie method.
-
-        Returns:
-            A dict respresentation of the JSON returned from the API.
-        """
-        path = self._get_id_path('videos')
-
-        response = self._GET(path, kwargs)
-        self._set_attrs_to_values(response)
-        return response
-
-    def translations(self, **kwargs):
-        """
-        Get the translations for a specific movie id.
-
-        Args:
-            append_to_response: (optional) Comma separated, any movie method.
-
-        Returns:
-            A dict respresentation of the JSON returned from the API.
-        """
-        path = self._get_id_path('translations')
-
-        response = self._GET(path, kwargs)
-        self._set_attrs_to_values(response)
-        return response
-
     def similar_movies(self, **kwargs):
         """
-        Get the similar movies for a specific movie id.
+        Get a list of similar movies. This is not the same as the
+        "Recommendation" system you see on the website.
+
+        These items are assembled by looking at keywords and genres.
 
         Args:
             page: (optional) Minimum value of 1.  Expected value is an integer.
@@ -224,7 +288,7 @@ class Movies(TMDB):
             append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('similar_movies')
 
@@ -234,7 +298,7 @@ class Movies(TMDB):
 
     def reviews(self, **kwargs):
         """
-        Get the reviews for a particular movie id.
+        Get the user reviews for a movie.
 
         Args:
             page: (optional) Minimum value of 1.  Expected value is an integer.
@@ -242,7 +306,7 @@ class Movies(TMDB):
             append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('reviews')
 
@@ -252,7 +316,7 @@ class Movies(TMDB):
 
     def lists(self, **kwargs):
         """
-        Get the lists that the movie belongs to.
+        Get a list of lists that this movie belongs to.
 
         Args:
             page: (optional) Minimum value of 1.  Expected value is an integer.
@@ -260,7 +324,7 @@ class Movies(TMDB):
             append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('lists')
 
@@ -268,34 +332,39 @@ class Movies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
-    def changes(self, **kwargs):
+    def rating(self, **kwargs):
         """
-        Get the changes for a specific movie id.
+        Rate a movie.
 
-        Changes are grouped by key, and ordered by date in descending order.
-        By default, only the last 24 hours of changes are returned. The
-        maximum number of days that can be returned in a single request is 14.
-        The language is present on fields that are translatable.
+        A valid session or guest session ID is required. You can read more
+        about how this works at
+        https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id.
 
         Args:
-            start_date: (optional) Expected format is 'YYYY-MM-DD'.
-            end_date: (optional) Expected format is 'YYYY-MM-DD'.
+            session_id: see Authentication.
+            guest_session_id: see Authentication.
+            value: Rating value.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
-        path = self._get_id_path('changes')
+        path = self._get_id_path('rating')
 
-        response = self._GET(path, kwargs)
+        payload = {
+            'value': kwargs.pop('value', None),
+        }
+
+        response = self._POST(path, kwargs, payload)
         self._set_attrs_to_values(response)
         return response
 
     def latest(self, **kwargs):
         """
-        Get the latest movie id.
+        Get the most newly created movie. This is a live response and will
+        continuously change.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_path('latest')
 
@@ -303,35 +372,22 @@ class Movies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
-    def upcoming(self, **kwargs):
-        """
-        Get the list of upcoming movies. This list refreshes every day.
-        The maximum number of items this list will include is 100.
-
-        Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
-            language: (optional) ISO 639-1 code.
-
-        Returns:
-            A dict respresentation of the JSON returned from the API.
-        """
-        path = self._get_path('upcoming')
-
-        response = self._GET(path, kwargs)
-        self._set_attrs_to_values(response)
-        return response
-
     def now_playing(self, **kwargs):
         """
-        Get the list of movies playing in theatres. This list refreshes
-        every day. The maximum number of items this list will include is 100.
+        Get a list of movies in theatres. This is a release type query that
+        looks for all movies that have a release type of 2 or 3 within the
+        specified date range.
+
+        You can optionally specify a region prameter which will narrow the
+        search to only look for theatrical release dates within the specified
+        country.
 
         Args:
             page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_path('now_playing')
 
@@ -341,15 +397,15 @@ class Movies(TMDB):
 
     def popular(self, **kwargs):
         """
-        Get the list of popular movies on The Movie Database. This list
-        refreshes every day.
+        Get a list of the current popular movies on TMDb. This list updates
+        daily.
 
         Args:
             page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_path('popular')
 
@@ -359,16 +415,14 @@ class Movies(TMDB):
 
     def top_rated(self, **kwargs):
         """
-        Get the list of top rated movies. By default, this list will only
-        include movies that have 10 or more votes. This list refreshes every
-        day.
+        Get the top rated movies on TMDb.
 
         Args:
             page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_path('top_rated')
 
@@ -376,44 +430,44 @@ class Movies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
-    def account_states(self, **kwargs):
+    def upcoming(self, **kwargs):
         """
-        This method lets users get the status of whether or not the movie has
-        been rated or added to their favourite or watch lists. A valid session
-        id is required.
+        Get a list of upcoming movies in theatres. This is a release type query
+        that looks for all movies that have a release type of 2 or 3 within the
+        specified date range.
+
+        You can optionally specify a region prameter which will narrow the
+        search to only look for theatrical release dates within the specified
+        country.
 
         Args:
-            session_id: see Authentication.
+            page: (optional) Minimum value of 1.  Expected value is an integer.
+            language: (optional) ISO 639-1 code.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
-        path = self._get_id_path('account_states')
+        path = self._get_path('upcoming')
 
         response = self._GET(path, kwargs)
         self._set_attrs_to_values(response)
         return response
 
-    def rating(self, **kwargs):
+    # backward compatability
+    def releases(self, **kwargs):
         """
-        This method lets users rate a movie. A valid session id or guest
-        session id is required.
+        Get the release date and certification information by country for a
+        specific movie id.
 
         Args:
-            session_id: see Authentication.
-            guest_session_id: see Authentication.
-            value: Rating value.
+            append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
-        path = self._get_id_path('rating')
+        path = self._get_id_path('releases')
 
-        payload = {
-            'value': kwargs.pop('value', None),
-        }
-
-        response = self._POST(path, kwargs, payload)
+        response = self._GET(path, kwargs)
         self._set_attrs_to_values(response)
         return response
 
@@ -428,6 +482,7 @@ class Collections(TMDB):
     URLS = {
         'info': '/{id}',
         'images': '/{id}/images',
+        'translations': '/{id}/translations',
     }
 
     def __init__(self, id):
@@ -436,19 +491,14 @@ class Collections(TMDB):
 
     def info(self, **kwargs):
         """
-        Get the basic collection information for a specific collection id.
-        You can get the ID needed for this method by making a /movie/{id}
-        request and paying attention to the belongs_to_collection hash.
-
-        Movie parts are not sorted in any particular order. If you would like
-        to sort them yourself you can use the provided release_date.
+        Get collection details by id.
 
         Args:
             language: (optional) ISO 639-1 code.
             append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('info')
 
@@ -458,7 +508,7 @@ class Collections(TMDB):
 
     def images(self, **kwargs):
         """
-        Get all of the images for a particular collection by collection id.
+        Get the images for a collection by id.
 
         Args:
             language: (optional) ISO 639-1 code.
@@ -467,7 +517,7 @@ class Collections(TMDB):
             ISO 69-1.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('images')
 
@@ -475,6 +525,23 @@ class Collections(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def translations(self, **kwargs):
+        """
+        Get a list of the translations for a collection by id.
+
+        Args:
+            language: (optional) ISO 639-1 code.
+            append_to_response: (optional) Comma separated, any movie method.
+
+        Returns:
+            A dict representation of the JSON returned from the API.
+        """
+        path = self._get_id_path('translations')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
 class Companies(TMDB):
     """
     Companies functionality.
@@ -484,7 +551,9 @@ class Companies(TMDB):
     BASE_PATH = 'company'
     URLS = {
         'info': '/{id}',
-        'movies': '/{id}/movies',
+        'alternative_names': '/{id}/alternative_names',
+        'images': '/{id}/images',
+        'movies': '/{id}/movies', # backward compatability
     }
 
     def __init__(self, id=0):
@@ -493,14 +562,13 @@ class Companies(TMDB):
 
     def info(self, **kwargs):
         """
-        This method is used to retrieve all of the basic information about a
-        company.
+        Get a companies details by id.
 
         Args:
             append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('info')
 
@@ -508,6 +576,47 @@ class Companies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def alternative_names(self, **kwargs):
+        """
+        Get the alternative names of a company.
+
+        Args:
+
+        Returns:
+            A dict representation of the JSON returned from the API.
+        """
+        path = self._get_id_path('alternative_names')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
+    def images(self, **kwargs):
+        """
+        Get a company's logos by id.
+
+        There are two image formats that are supported for companies, PNG's and
+        SVG's. You can see which type the original file is by looking at the
+        file_type field. We prefer SVG's as they are resolution independent and
+        as such, the width and height are only there to reflect the original
+        asset that was uploaded.  An SVG can be scaled properly beyond those
+        dimensions if you call them as a PNG.
+
+        For more information about how SVG's and PNG's can be used, take a read
+        through https://developers.themoviedb.org/3/getting-started/images.
+
+        Args:
+
+        Returns:
+            A dict representation of the JSON returned from the API.
+        """
+        path = self._get_id_path('images')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
+    # backward compatability
     def movies(self, **kwargs):
         """
         Get the list of movies associated with a particular company.
@@ -518,7 +627,7 @@ class Companies(TMDB):
             append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('movies')
 
@@ -526,6 +635,7 @@ class Companies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+
 class Keywords(TMDB):
     """
     Keywords functionality.
@@ -544,10 +654,10 @@ class Keywords(TMDB):
 
     def info(self, **kwargs):
         """
-        Get the basic information for a specific keyword id.
+        Get the details of a keyword.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('info')
 
@@ -557,14 +667,17 @@ class Keywords(TMDB):
 
     def movies(self, **kwargs):
         """
-        Get the list of movies for a particular keyword by id.
+        Get the movies that belong to a keyword.
+
+        We highly recommend using movie discover instead of this method as it
+        is much more flexible.
 
         Args:
             page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('movies')
 
@@ -589,10 +702,10 @@ class Reviews(TMDB):
 
     def info(self, **kwargs):
         """
-        Get the full details of a review by ID.
+        Get the review details by id.
 
         Returns:
-            A dict respresentation of the JSON returned from the API.
+            A dict representation of the JSON returned from the API.
         """
         path = self._get_id_path('info')
 
